Python: module VirtualEnvOnDemand.utils

VirtualEnvOnDemand.utils | index

`utils - Some general-purpose utility functions`

Modules
`` |  |
re |  |  |

Functions
`` |  | cmp_version(version1, version2) `cmp_version - Compare version1 and version2. Returns cmp-style (C-style), i.e. < 0 if lefthand (version1) is less, 0 if equal, > 0 if righthand (version2) is greater. @param version1 <str> - String of a version @param version2 <str> - String of a version @return <int> - -1 if version1 is < version2 0 if version1 is = version2 1 if version1 is > version2`

Data
`` |  | __all__ = ('cmp_version',)